@@ -1,8 +1,8 @@
 package App::GitGot;
-$App::GitGot::VERSION = '1.23'; # TRIAL
+$App::GitGot::VERSION = '1.26'; # TRIAL
 # ABSTRACT: A tool to make it easier to manage multiple git repositories.
 use 5.014;
-use feature 'unicode_strings';
+use warnings;
 
 use App::Cmd::Setup -app;
 
@@ -21,7 +21,7 @@ App::GitGot - A tool to make it easier to manage multiple git repositories.
 
 =head1 VERSION
 
-version 1.23
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -33,7 +33,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
