@@ -1,8 +1,7 @@
 package App::GitGot::Command::add;
-$App::GitGot::Command::add::VERSION = '1.23'; # TRIAL
+$App::GitGot::Command::add::VERSION = '1.26'; # TRIAL
 # ABSTRACT: add a new repo to your config
 use 5.014;
-use feature 'unicode_strings';
 
 use Class::Load              qw/ try_load_class /;
 use Config::INI::Reader;
@@ -11,7 +10,6 @@ use IO::Prompt::Simple;
 use List::AllUtils           qw/ any pairmap /;
 use Path::Tiny;
 use PerlX::Maybe;
-use Term::ReadLine;
 use Types::Standard -types;
 
 use App::GitGot -command;
@@ -30,6 +28,8 @@ sub options {
   );
 }
 
+sub _use_io_page { 0 }
+
 sub _execute {
   my ( $self, $opt, $args ) = @_;
 
@@ -132,7 +132,7 @@ App::GitGot::Command::add - add a new repo to your config
 
 =head1 VERSION
 
-version 1.23
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -154,7 +154,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
