@@ -1,12 +1,11 @@
 package App::GitGot::Command::clone;
-$App::GitGot::Command::clone::VERSION = '1.23'; # TRIAL
+$App::GitGot::Command::clone::VERSION = '1.26'; # TRIAL
 # ABSTRACT: clone a remote repo and add it to your config
 use 5.014;
-use feature 'unicode_strings';
 
 use Cwd;
 use Path::Tiny;
-use Term::ReadLine;
+use IO::Prompt::Simple;
 use Types::Standard -types;
 
 use App::GitGot -command;
@@ -33,20 +32,18 @@ sub _execute {
   my $cwd = getcwd
     or( say STDERR "ERROR: Couldn't determine path" and exit(1) );
 
-
   my $name = path( $repo )->basename;
   $name =~ s/.git$//;
 
   $path //= "$cwd/$name";
-  $path = File::Spec->rel2abs( $path );
+  $path = path( $path )->absolute;
 
   my $tags;
 
   unless ( $self->opt->defaults ) {
-    my $term = Term::ReadLine->new('gitgot');
-    $name = $term->readline( 'Name: ', $name );
-    $path = $term->readline( 'Path: ', $path );
-    $tags = $term->readline( 'Tags: ', $tags );
+    $name = prompt( 'Name: ' , $name );
+    $path = prompt( 'Path: ' , $path );
+    $tags = prompt( 'Tags: ' , $tags );
   }
 
   my $new_entry = App::GitGot::Repo::Git->new({ entry => {
@@ -79,7 +76,7 @@ App::GitGot::Command::clone - clone a remote repo and add it to your config
 
 =head1 VERSION
 
-version 1.23
+version 1.26
 
 =head1 AUTHOR
 
@@ -87,7 +84,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
