@@ -1,13 +1,12 @@
 package App::GitGot::Command::fork;
-$App::GitGot::Command::fork::VERSION = '1.23'; # TRIAL
+$App::GitGot::Command::fork::VERSION = '1.26'; # TRIAL
 # ABSTRACT: fork a github repo
 use 5.014;
-use feature 'unicode_strings';
 
 use autodie;
 use Class::Load       'try_load_class';
 use Cwd;
-use File::Slurp::Tiny 'read_lines';
+use Path::Tiny;
 use Types::Standard -types;
 
 use App::GitGot -command;
@@ -60,7 +59,7 @@ sub _parse_github_identity {
   -e $file or
     say STDERR "ERROR: Can't find $ENV{HOME}/.github-identity" and exit(1);
 
-  my @lines = read_lines( $file );
+  my @lines = path( $file )->lines;
 
   my %config;
   foreach ( @lines ) {
@@ -107,7 +106,7 @@ App::GitGot::Command::fork - fork a github repo
 
 =head1 VERSION
 
-version 1.23
+version 1.26
 
 =head1 AUTHOR
 
@@ -115,7 +114,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
