@@ -1,8 +1,7 @@
 package App::GitGot::Repo;
-$App::GitGot::Repo::VERSION = '1.23'; # TRIAL
+$App::GitGot::Repo::VERSION = '1.26'; # TRIAL
 # ABSTRACT: Base repository objects
 use 5.014;
-use feature 'unicode_strings';
 
 use List::AllUtils qw/ uniq /;
 use Types::Standard -types;
@@ -37,6 +36,7 @@ has path => (
   is       => 'ro',
   isa      => Str,
   required => 1 ,
+  coerce   => sub { ref $_[0] && $_[0]->isa('Path::Tiny') ? "$_[0]" : $_[0] } ,
 );
 
 
@@ -136,7 +136,7 @@ App::GitGot::Repo - Base repository objects
 
 =head1 VERSION
 
-version 1.23
+version 1.26
 
 =head1 ATTRIBUTES
 
@@ -191,7 +191,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
