@@ -1,10 +1,8 @@
 package App::GitGot::Types;
-$App::GitGot::Types::VERSION = '1.23'; # TRIAL
+$App::GitGot::Types::VERSION = '1.26'; # TRIAL
 # ABSTRACT: GitGot type library
-use strict;
+use 5.014;    ## strict, unicode_strings
 use warnings;
-use 5.014;
-use feature 'unicode_strings';
 
 use Type::Library
   -base ,
@@ -34,7 +32,7 @@ App::GitGot::Types - GitGot type library
 
 =head1 VERSION
 
-version 1.23
+version 1.26
 
 =head1 AUTHOR
 
@@ -42,7 +40,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
